@@ -17,8 +17,8 @@ package Dist::Zilla::Plugin::TemplateCJM;
 # ABSTRACT: Process templates, including version numbers & changes
 #---------------------------------------------------------------------
 
-our $VERSION = '5.000';
-# This file is part of Dist-Zilla-Plugin-TemplateCJM 5.000 (December 5, 2015)
+our $VERSION = '5.001';
+# This file is part of Dist-Zilla-Plugin-TemplateCJM 5.001 (December 12, 2015)
 
 
 use Moose;
@@ -47,11 +47,15 @@ has changelog => (
 );
 
 
-coerce 'RegexpRef', from 'Str', via { qr/$_/ };
+use constant _CoercedRegexp => do {
+    my $tc = subtype as 'RegexpRef';
+    coerce $tc, from 'Str', via { qr/$_/ };
+    $tc;
+};
 
 has changelog_re => (
   is   => 'ro',
-  isa  => 'RegexpRef',
+  isa  => _CoercedRegexp,
   coerce   => 1,
   default  => sub { qr/(\d[\d._]*)\s+(.+)/ },
 );
@@ -469,8 +473,8 @@ Dist::Zilla::Plugin::TemplateCJM - Process templates, including version numbers
 
 =head1 VERSION
 
-This document describes version 5.000 of
-Dist::Zilla::Plugin::TemplateCJM, released December 5, 2015.
+This document describes version 5.001 of
+Dist::Zilla::Plugin::TemplateCJM, released December 12, 2015.
 
 =head1 SYNOPSIS
 
